@@ -85,14 +85,14 @@ class EntryPointPluginLoader(PluginLoader):
 
 
 class _PluginProperty(object):
-    def __init__(self, default=None, type_=False, required=False):
+    def __init__(self, default=None, type_=None, required=False):
         self.default = default
         self.required = required
 
-        self.type = default.__class__ if (default is not None and type_ is False) else type_
+        self.type = default.__class__ if (default is not None and type_ is None) else type_
 
     def coerce(self, value):
-        if self.type is False or isinstance(value, self.type):
+        if self.type in (False, None) or isinstance(value, self.type):
             return value
         return self.type(value)
 
@@ -235,12 +235,12 @@ class Plugin:
                 t._stop()
         self._tasks = []
         
-    def send(self, l, parseColors=False):
-        self.dispatch(ServerInput(line=l, parse_colors=parseColors))
+    def send(self, l):
+        self.dispatch(ServerInput(line=l))
 
-    def send_format(self, l, parseColors=False, **kw):
+    def send_format(self, l, **kw):
         kw = dict((k, FormatWrapper(v)) for k, v in kw.iteritems())
-        self.send(l.format(**kw), parseColors=parseColors)
+        self.send(l.format(**kw))
     
     def action_chain_cancellable(self, spec, callbackWarn, callbackAction, callbackCancel=None):
         intervals = [self.parse_time(i) for i in spec.split(';')]
