@@ -1,11 +1,12 @@
 import feedparser
-import res
+import re
 from twisted.web.client import getPage
 
 from mk2.plugins import Plugin
 
 reddit_link = re.compile('http://(?:www\.)?redd(?:\.it/|it\.com/(?:tb|(?:r/[\w\.]+/)?comments)/)(\w+)(/.+/)?(\w{7})?')
 
+
 #Many thanks to Adam Wight for this
 class FeedPoller(object):
     last_seen_id = None
@@ -23,10 +24,11 @@ class FeedPoller(object):
         if result.entries:
             self.last_seen_id = result.entries[-1].id
 
+
 class RSS(Plugin):
-    url            = ""
-    check_interval = 60
-    command        = "say {link} - {title}"
+    url = Plugin.Property(default="")
+    check_interval = Plugin.Property(default=60)
+    command = Plugin.Property(default="say {link} - {title}")
     
     def setup(self):
         self.poller = FeedPoller()
@@ -44,4 +46,4 @@ class RSS(Plugin):
             m = reddit_link.match(entry['link'])
             if m:
                 entry['link'] = "http://redd.it/" + m.group(1)
-            self.send_format(self.command, parseColors=True, **entry)
+            self.send_format(self.command, **entry)
