@@ -21,12 +21,14 @@ class ProcessProtocol(protocol.ProcessProtocol):
         self.dispatch(events.ServerOutput(line=line))
 
     def childDataReceived(self, fd, data):
+        if data[0] == '\b':
+            data = data.lstrip(' \b')
         data = data.decode(self.locale)
         data = data.split("\n")
         data[0] = self.obuff + data[0]
         self.obuff = data.pop()
         for l in data:
-            self.output(l)
+            self.output(l.strip('\r'))
 
     def makeConnection(self, transport):
         self.dispatch(events.ServerStarting(pid=transport.pid))
